// FILE: ./assets/js/utilities/FACUtil.js
/* global Util angular Configuration moment */
var FACUtil = function(templateManager, MessageService) {
    var trataNumerico = function(value, decimalSeparator) {
        if (typeof value == "number") {
            return value.toString().split(".").join(decimalSeparator);
        }
        return (value) ? value.toString() : value + '';
    };

    /*
     * Usar no FieldOnKeydown
     *
     */

    this.lengthCurrency = function(args) {
        var value;
        var fieldValue;
        var field = args.owner.field;
        var allowedKeys = ['Tab', 'ArrowLeft', 'ArrowRight', 'ArrowUp', 'ArrowDown', 'End', 'Home', 'Shift', 'Control', 'Delete', 'Backspace', 'Alt'];

        let decimalSeparator = ',';
        let thousandSeparator = '.';

        if (field.mask && field.mask.params && field.mask.params.decimal) {
            decimalSeparator = field.mask.params.decimal;
        }

        if (field.inlineEditable && (field.widget.mode === "list" || field.widget.mode === "inline_edit")) {
            fieldValue = trataNumerico(field.widget.currentRow[field.name + '_inline'], decimalSeparator);
            fieldValue = fieldValue.toString();
            if (event.target.selectionStart !== event.target.selectionEnd) {
                fieldValue = fieldValue.substring(0, event.target.selectionStart) || fieldValue.substring(event.target.selectionEnd);
            }
            value = Util.isEmptyOrBlank(fieldValue) ? "" : fieldValue;
        } else {
            fieldValue = trataNumerico(field.value(), decimalSeparator);
            fieldValue = fieldValue.toString();
            if (event.target.selectionStart !== event.target.selectionEnd) {
                fieldValue = fieldValue.substring(0, event.target.selectionStart) || fieldValue.substring(event.target.selectionEnd);
            }
            value = Util.isEmptyOrBlank(fieldValue) ? "" : fieldValue;
        }

        fieldValue = fieldValue.toString();
        if (event.target.selectionStart !== event.target.selectionEnd) {
            fieldValue = fieldValue.substring(0, event.target.selectionStart) || fieldValue.substring(event.target.selectionEnd);
        }

        let posInsertChar = event.target.selectionStart;

        var realLength = value.split('-').join('').split('.').join('').split(',')[0].length;
        var last = Math.max(...[value.lastIndexOf(','), value.lastIndexOf('.')]);
        var separador;
        var decimalLength = value.split('-').join('').split('.').join('').split(',')[1] ? value.split('-').join('').split('.').join('').split(',')[1].length : 0;
        var precisionLength = 0;

        if (field.mask && field.mask.params && field.mask.params.precision) {
            precisionLength = field.mask.params.precision;
        }

        if (last > -1) {
            separador = value.substring(0, last).length >= field.maxLengthCurrency - precisionLength ? ',' : value[last];
            value = value.substr(0, last).concat(separador + value.substr(last + 1, value.length));
            value = value.split('.').join('');
            last = value.lastIndexOf(',');
            realLength = value.substr(0, last).length;
            decimalLength = value.substr(last + 1, value.length).length;
        }

        let isDecimalSeparator = (args.e.key === decimalSeparator);
        let allowDecimalSeparator = ((precisionLength > 0) && (!value.includes(decimalSeparator)));
        let posDecimalseparator = fieldValue.indexOf(decimalSeparator);
        if (isDecimalSeparator && !allowDecimalSeparator) {
            args.e.preventDefault();
        }

        if (field.mask && field.mask.params && field.mask.params.thousands) {
            thousandSeparator = field.mask.params.thousands;
        }
        let isThousandSeparator = (args.e.key === thousandSeparator);

        if (isThousandSeparator) {
            args.e.preventDefault();
        }

        let allowNegative = true;
        if (field.mask && field.mask.params) {
            allowNegative = field.mask.params.allowNegative;
        }
        allowNegative = (allowNegative && !value.includes('-'));
        let isNegativeSimbol = (args.e.key === '-');

        if (isNegativeSimbol && (!allowNegative || (event.target.selectionStart > 0))) {
            args.e.preventDefault();
        }
        if (!allowedKeys.includes(args.e.key) && !isNegativeSimbol && !isDecimalSeparator && !isThousandSeparator) {
            if (realLength >= field.maxLengthCurrency) {
                if ((posDecimalseparator < 0) || (posInsertChar <= posDecimalseparator))
                    args.e.preventDefault();
            }

            if ((posDecimalseparator >= 0) && (posInsertChar > posDecimalseparator) && (precisionLength == decimalLength)) {
                args.e.preventDefault();
            }
        }
    };

    this.blockDependentField = function(field, nameFields, modifyValidations = false, treatFirstNode = true) {
        nameFields = Array.isArray(nameFields) ? nameFields : [nameFields];
        const widget = field.widget;
        let firstNode = nameFields[0];
        const fieldValue = field.value();
        let fieldFirstNode = widget.getField(firstNode);
        nameFields.forEach(nameField => {
            let cField = widget.getField(nameField);
            if (cField) {
                cField.readOnly = true;
                if (modifyValidations) changeValidations(cField);
            }
        });
        if (fieldFirstNode && treatFirstNode) {
            fieldFirstNode.readOnly = !fieldValue;
            if (modifyValidations) changeValidations(fieldFirstNode);
        }
        templateManager.updateTemplate();
    };

    function changeValidations(field) {
        field.validations = field.readOnly ? {} : {
            required: true
        };
    }

    this.updateFilterFields = function(fieldsUpdate, nameFilters, rowToSet, reloadField = false, widget = null) {
        nameFilters = typeof nameFilters === 'string' ? [nameFilters] : nameFilters;
        fieldsUpdate = Array.isArray(fieldsUpdate) ? fieldsUpdate : [fieldsUpdate];
        reloadField = typeof reloadField == 'string' ? [reloadField] : reloadField;
        fieldsUpdate.forEach(cField => {
            cField = typeof cField == 'string' ? widget.getField(cField) : cField;
            if (cField && cField.dataSourceFilter) {
                let oldDataSourceFilter = angular.copy(cField.dataSourceFilter);
                cField.dataSourceFilter.forEach(filter => {
                    if (nameFilters.indexOf(filter.name) > -1) {
                        filter.value = rowToSet[filter.name];
                    }
                });
                if (reloadField == true || (Array.isArray(reloadField) && reloadField.indexOf(cField.name) > -1)) this.reloadField(cField, oldDataSourceFilter);
            }
        });
    };

    this.reloadField = function(field, oldDataSourceFilter = null) {
        let reloaded = false;
        if (field) {
            if (field.dataSourceFilter && oldDataSourceFilter && !angular.equals(field.dataSourceFilter, oldDataSourceFilter)) {
                field.reload();
                reloaded = true;
            } else {
                field.reload();
                reloaded = true;
            }
        }
        return reloaded;
    };

    this.getValuesInRow = function(widget, fieldAndPropValue, emptyProps = [], emptyValue = '') { // {FIELDNAME: NAME_GET_ROW}
        let result = {};
        emptyProps = Array.isArray(emptyProps) ? emptyProps : [emptyProps];
        Object.keys(fieldAndPropValue).forEach(nameField => {
            let cField = widget.getField(nameField);
            if (cField) {
                let valueFields = Array.isArray(fieldAndPropValue[nameField]) ? fieldAndPropValue[nameField] : [fieldAndPropValue[nameField]];
                let fieldValue = cField.value();
                valueFields.forEach(valueField => {
                    result[valueField] = fieldValue ? widget.currentRow[valueField] : '';
                });
            }
        });
        emptyProps.forEach(prop => {
            result[prop] = emptyValue;
        });
        return result;
    };

    this.clearDataSourceFilter = function(widget, fields, fieldsToReload = [], flagIgnoreValueInFilter = 'T') {
        widget = typeof widget === 'string' ? templateManager.container.getWidget(widget) : widget;
        fieldsToReload = typeof fieldsToReload === 'string' ? [fieldsToReload] : fieldsToReload;
        fields = Array.isArray(fields) ? fields : [fields];
        fields.forEach(nameField => {
            let field = widget.getField(nameField);
            if (field && field.dataSourceFilter && field.dataSourceFilter.length) {
                field.dataSourceFilter.forEach(filter => {
                    if (flagIgnoreValueInFilter !== false) {
                        filter.value = filter.value === flagIgnoreValueInFilter ? filter.value : '';
                    } else {
                        filter.value = "";
                    }
                });
                if (fieldsToReload.indexOf(field.name) > -1) field.reload();
            }
        });
    };

    this.clearSelectMultiple = function(field) {
        let widget = field.widget;
        let row = widget.currentRow;
        if (field.valueField && field.descriptionField) {
            let {
                valueField,
                descriptionField
            } = field;
            row[valueField] = [];
            row[descriptionField] = [];
        }
    };

    function changeFieldCheckbox(widget, field, nameFieldCheckbox) {
        let fieldCheckbox = widget.getField(nameFieldCheckbox);
        let row = widget.currentRow;
        if (fieldCheckbox) {
            row[nameFieldCheckbox] = field.readOnly ? fieldCheckbox.valueToTrue : fieldCheckbox.valueToFalse;
            fieldCheckbox.checked = field.readOnly;
            changeValidations(field);
        }
    }

    this.defaultClearField = function(field) {
        let widget = field.widget;
        let row = widget.currentRow;
        let valueToSet = "";
        if (field.valueField && field.descriptionField) {
            let {
                valueField,
                descriptionField
            } = field;
            row[valueField] = valueToSet;
            row[descriptionField] = valueToSet;
        } else if (field.outData) {
            Object.values(field.outData).forEach(itemRow => {
                row[itemRow] = valueToSet;
            });
        } else if (field.valueFields) {
            field.valueFields.forEach(itemRow => {
                row[itemRow] = valueToSet;
            });
        }
    };

    this.clearFields = function(widget, nameFields = [], fieldNameAndCheckbox = null) {
        let functionByTemplate = Object.freeze({
            "field/select-multiple.html": this.clearSelectMultiple,
            default: this.defaultClearField
        });
        nameFields = Array.isArray(nameFields) ? nameFields : [nameFields];
        nameFields.forEach(nameField => {
            let field = widget.getField(nameField);
            if (field) {
                let functionClearField = Object.keys(functionByTemplate).find(template => {
                    return field.template.indexOf(template) > -1;
                });
                functionClearField = functionByTemplate[functionClearField] || functionByTemplate.default;
                functionClearField(field);
                if (fieldNameAndCheckbox) {
                    if (typeof fieldNameAndCheckbox == 'string') {
                        changeFieldCheckbox(widget, field, fieldNameAndCheckbox);
                    } else if (typeof fieldNameAndCheckbox == 'object' && !Array.isArray(fieldNameAndCheckbox)) {
                        if (fieldNameAndCheckbox[field.name])
                            changeFieldCheckbox(widget, field, fieldNameAndCheckbox[field.name]);
                    }
                }
            }
        });
    };

    function getDatesInRow(widget, fieldStartDate, fieldEndDate) {
        let row = widget.currentRow;
        return {
            startDate: row[fieldStartDate.name],
            endDate: row[fieldEndDate.name]
        };
    }

    function isValidRange(startDate, endDate) {
        return !moment(endDate, 'DD/MM/YYYY').isBefore(moment(startDate, 'DD/MM/YYYY'));
    }

    this.onChangeDate = function(args, fieldStartDate, fieldEndDate, showMessage = true) {
        const currentField = args.owner.field;
        const widget = currentField.widget;
        fieldStartDate = typeof fieldStartDate == 'string' ? widget.getField(fieldStartDate) : fieldStartDate;
        fieldEndDate = typeof fieldEndDate == 'string' ? widget.getField(fieldEndDate) : fieldEndDate;
        if (fieldStartDate && fieldEndDate) {
            if (!fieldStartDate.value() || !fieldEndDate.value()) return;
            let {
                startDate,
                endDate
            } = getDatesInRow(widget, fieldStartDate, fieldEndDate);
            let isValidRangeDate = isValidRange(startDate, endDate);
            if (!isValidRangeDate) {
                fieldEndDate.clearValue(fieldEndDate);
                if (showMessage) MessageService.showMessageByCode("MSG_FAC_DATAINICIAL_MENOR_DATAFINAL");
                return false;
            }
        }
    };

};

Configuration(function(ContextRegister) {
    ContextRegister.register("FACUtil", FACUtil);
});

// FILE: ./assets/js/services/fac00100_calculo_de_apuracao_service.js
var fac00100_calculo_de_apuracao_service = function(General, restEngine) {
    this.findFilial = function() {
        return restEngine.post("fac#/crud/filial", {
            "requestType": "FilterData",
            "filter": [
                {
                    "name": "NRORG",
                    "operator": "=",
                    "value": getLocalVar('INFLIGHTOR_NRORGTRAB')
                },
                {
                    "name": "CDFILIAL",
                    "operator": "=",
                    "value": 'FILIAL_LOGADA'
                }
            ]
        });
    };
    this.calculaDataFechamento = function(filter) {
        return restEngine.post("fac#/crud/fac00100_perfecham", {
            "requestType": "FilterData",
            "filter": filter
        });
    };
    this.apurar = function(data) {
        return restEngine.post("fac#/fac00100_apurarfaturamento", {
            "requestType": "DataSet",
            "dataset": data
        });
    };
};
Configuration(function(ContextRegister, eventEngine) {
    ContextRegister.register('fac00100_calculo_de_apuracao_service', fac00100_calculo_de_apuracao_service);
});

// FILE: ./assets/js/services/fac00200_cancelamento_de_apuracao_service.js
var fac00200_cancelamento_de_apuracao_service = function(General, restEngine) {
    this.findFilial = function() {
        return restEngine.post("ate#/crud/filial", {
            "requestType": "FilterData",
            "filter": [
                {
                    "name": "NRORG",
                    "operator": "=",
                    "value": getLocalVar('INFLIGHTOR_NRORGTRAB')
                },
                {
                    "name": "CDFILIAL",
                    "operator": "=",
                    "value": 'FILIAL_LOGADA'
                }
            ]
        });
    };
    this.procedureCancelamento = function(data) {
        return restEngine.post("fac#/fac00200_cancela_apuracao", {
            "requestType": "DataSet",
            "dataset": data
        });
    };
    this.verificaNF = function(filter) {
        return restEngine.post("fac#/crud/fac00200_verifica_nf", {
            "requestType": "FilterData",
            "filter": filter
        });
    };
};
Configuration(function(ContextRegister, eventEngine) {
    ContextRegister.register('fac00200_cancelamento_de_apuracao_service', fac00200_cancelamento_de_apuracao_service);
});

// FILE: ./assets/js/controllers/fac00100_calculo_de_apuracao_controller.js
var fac00100_calculo_de_apuracao_controller = function(ScreenService, General, fac00100_calculo_de_apuracao_service, ZHPromise, MessageService, InflightorGeneral) {
    var self = this;

    var messages = {
        dtMenorMaiorDelivery: "Data inicial (delivery) deve ser menor ou igual a data final (delivery).",
        dtFinalAtual: "Data final de apuração de delivery deve ser menor ou igual a data de hoje.",
        dtFinalFaturamento: "Data final deve ser menor ou igual a data de faturamento.",
        dtAnoInicial: "O ano da data inicial digitada é menor do que o ano da data atual, deseja confirmar?",
        dtAnoFaturamento: "O ano da data de faturamento digitada é menor do que o ano da data atual, deseja confirmar?",
        semTipoFaturamento: "Tipo de faturamento não cadastrado para a companhia.",
        semNotas: "Não foram geradas notas fiscais no período informado.",
        tipoApuracInvalido: "Tipo de apuração informado é inválido."
    };

    this.setDefaultFilial = function(args) {
        args.owner.currentRow.CDFILIAL = getLocalVar('INFLIGHTOR_CDFILIAL');
        args.owner.currentRow.NMFILIAL = getLocalVar('INFLIGHTOR_NMFILIAL');
        self.onChangeUnidade(args.owner);
    };
    this.onChangeUnidade = function(widget) {
        ciaField = widget.getField('NMCIA');
        serieField = widget.getField('DSSERIE');
        if (widget.currentRow.CDFILIAL) {
            ciaField.dataSourceFilter[0].value = widget.currentRow.CDFILIAL;
            serieField.dataSourceFilter[0].value = widget.currentRow.CDFILIAL;
            ciaField.reload();
            serieField.reload();
        } else {
            ciaField.dataSourceFilter[0].value = "";
            serieField.dataSourceFilter[0].value = "";
            ciaField.reload();
            serieField.reload();
        }
        widget.currentRow.NMCIA = '';
        widget.currentRow.DSSERIE = '';
        widget.currentRow.DSTIPEMNF = '';
        widget.currentRow.DTULTFECH = '';
        widget.currentRow.DTPROXFECH = '';
    };
    this.onChangeCia = function(widget) {
        self.calculaDataFechamento(widget);
        var idtipemnf = widget.currentRow.IDTIPEMNF;
        var vooField = widget.getField('NRVOO');
        var vooFieldTodos = widget.getField('TNRVOO');
        if (idtipemnf == '02' || idtipemnf == '03' || idtipemnf == '12') {
            widget.getField('AGRUPSERV').readOnly = true;
        } else {
            widget.getField('AGRUPSERV').readOnly = false;
        }
        vooField.value('T');
        vooField.readOnly = true;
        vooFieldTodos.checked = true;
        vooFieldTodos.setValue('S');
        vooField.validations = {};
        if (idtipemnf == '01' || idtipemnf == '04' || idtipemnf === null) {
            vooFieldTodos.readOnly = true;
        } else {
            vooFieldTodos.readOnly = false;
        }
        vooField.dataSourceFilter[0].value = widget.currentRow.CDFILIAL;
        vooField.dataSourceFilter[1].value = widget.currentRow.CDCIA;
        vooField.dataSourceFilter[2].value = null;
        vooField.reload();
    };
    this.calculaDataFechamento = function(widget) {
        var row = widget.currentRow;
        var dataFech = moment(row.DTULTFECH, 'DD/MM/YYYY hh:mm:ss');
        if (row.IDCALCPROXFAT == 'S') {
            if (!row.DTULTFECH) {
                row.DTPROXFECH = null;
            } else {
                var filter = [
                    {
                        "name": "CDFILIAL",
                        "operator": "=",
                        "value": row.CDFILIAL
                    },
                    {
                        "name": "CDCIA",
                        "operator": "=",
                        "value": row.CDCIA
                    },
                    {
                        "name": "DIFECHCIA",
                        "operator": "=",
                        "value": dataFech.format('DD')
                    }
                ];
                fac00100_calculo_de_apuracao_service.calculaDataFechamento(filter).then(function(callback) {
                    if (callback.dataset.fac00100_perfecham.length) {
                        var dia = callback.dataset.fac00100_perfecham[0].DIFECHCIA;
                        if (dia > dataFech.endOf('month').format('DD')) {
                            row.DTPROXFECH = dataFech.endOf('month').format('DD/MM/YYYY');
                        } else {
                            row.DTPROXFECH = dia + dataFech.format('/MM/YYYY');
                        }
                    } else {
                        row.DTPROXFECH = dataFech.add(1, 'month').format('DD/MM/YYYY');
                    }
                    row.DTINICIAL = row.DTPROXFECH;
                    row.DTFINAL = row.DTPROXFECH;
                    row.DTFATUR = row.DTPROXFECH;
                });
            }
        }
    };
    this.apurar = function(widget) {
        if (widget.isValid()) {
            self.validaDatas(widget.currentRow).then(function() {
                if (widget.currentRow.IDTIPEMNF === null) {
                    // ScreenService.showMessage(messages.semTipoFaturamento, 'error');
                    MessageService.showMessageByCode("FAC00100_SEMTIPOFAT");
                } else {
                    if (widget.getField('TNRVOO').checked) {
                        widget.currentRow.P_NRVOO = 'T';
                    } else {
                        widget.currentRow.P_NRVOO = "_" + widget.currentRow.NRVOO.join('_');
                    }
                    fac00100_calculo_de_apuracao_service.apurar([widget.currentRow]).then(function(callback) {
                        MessageService.showMessageByCode("FAC00100_SUCESS");
                        self.exibirNotas(widget, callback);
                    }).catch(function(error) {
                        errorMessage = "Timeout";
                        if (error.data && (error.data.error.indexOf("APPERRMSGSTRAPP-00033APPERRMSGEND") != -1)) {
                            // errorMessage = messages.tipoApuracInvalido;
                            MessageService.showMessageByCode("FAC00100_TIPOAPURACINV");
                        } else {
                            errorMessage = error.data.error;
                            ScreenService.showMessage(errorMessage, 'error');
                        }
                    });
                }
            });
        }
        // ScreenService.openPopup(widget.container.getWidget('notasPopup'));
    };
    this.exibirNotas = function(widget, callback) {
        if (callback.dataset && callback.dataset.fac00100_notafiscal.length) {
            widget.container.getWidget('notasPopup').dataSource.data = callback.dataset.fac00100_notafiscal;
            widget.container.getWidget('stripefooter_totais').currentRow.VRTOTAAPUR = callback.dataset.fac00100_notafiscal[0].VRTOTAAPUR;
            widget.container.getWidget('stripefooter_totais').currentRow.VRTOTAAPURESTR = callback.dataset.fac00100_notafiscal[0].VRTOTAAPURESTR;
            ScreenService.openPopup(widget.container.getWidget('notasPopup'));
        } else {
            // ScreenService.showMessage(messages.semNotas, 'error');
            MessageService.showMessageByCode("FAC00100_SEMNOTA");
        }
    };
    this.validaDatas = function(row) {
        var deferred = ZHPromise.defer();
        var dtInicial = moment(row.DTINICIAL, 'DD/MM/YYYY');
        var dtFinal = moment(row.DTFINAL, 'DD/MM/YYYY');
        var dtFatur = moment(row.DTFATUR, 'DD/MM/YYYY');
        var dtAtual = moment();
        if (dtInicial > dtFinal) {
            // ScreenService.showMessage(messages.dtMenorMaiorDelivery, 'error');
            MessageService.showMessageByCode("FAC00100_DTMENORMAIORDEL");
            deferred.reject();
        } else if (dtFinal > dtFatur) {
            // ScreenService.showMessage(messages.dtFinalFaturamento, 'error');
            MessageService.showMessageByCode("FAC00100_DTFINALFAT");
            deferred.reject();
        } else if (dtFinal > dtAtual) {
            // ScreenService.showMessage(messages.dtFinalAtual, 'error');
            MessageService.showMessageByCode("FAC00100_DTFINALATUAL");
            deferred.reject();
        } else if (dtInicial.format('YYYY') < dtAtual.format('YYYY')) {
            MessageService.confirmMessageByCode("FAC00100_DTANOINICIAL").then(() => {
                if (dtFatur.format('YYYY') < dtAtual.format('YYYY')) {
                    MessageService.confirmMessageByCode("FAC00100_DTANOFAT").then(() => {
                        deferred.resolve();
                    }, () => {
                        deferred.reject();
                    });
                } else {
                    deferred.reject();
                }
            });
            // ScreenService.confirmMessage(messages.dtAnoInicial, 'question').then(function() {
            //     if (dtFatur.format('YYYY') < dtAtual.format('YYYY')) {
            //         ScreenService.confirmMessage(messages.dtAnoFaturamento, 'question').then(function() {
            //             deferred.resolve();
            //         }, function() {
            //             deferred.reject();
            //         });
            //     } else {
            //         deferred.resolve();
            //     }
            // }, function() {
            //     deferred.reject();
            // });
        } else if (dtFatur.format('YYYY') < dtAtual.format('YYYY')) {
            MessageService.confirmMessageByCode("FAC00100_DTANOFAT").then(() => {
                deferred.resolve();
            }, () => {
                deferred.reject();
            });
            // ScreenService.confirmMessage(messages.dtAnoFaturamento, 'question').then(function() {
            //     deferred.resolve();
            // }, function() {
            //     deferred.reject();
            // });
        } else {
            deferred.resolve();
        }
        return deferred.promise;
    };

    this.getMensagens = function() {
        MessageService.getMessagesByCode(["FAC00100_DTMENORMAIORDEL", "FAC00100_DTFINALATUAL",
                                          "FAC00100_DTFINALFAT", "FAC00100_DTANOINICIAL",
                                          "FAC00100_DTANOFAT", "FAC00100_SEMTIPOFAT",
                                          "FAC00100_SEMNOTA", "FAC00100_TIPOAPURACINV"]).then(function(mensagens) {
            messages.dtMenorMaiorDelivery = ScreenService.i18n(mensagens[0]);
            messages.dtFinalAtual = ScreenService.i18n(mensagens[1]);
            messages.dtFinalFaturamento = ScreenService.i18n(mensagens[2]);
            messages.dtAnoInicial = ScreenService.i18n(mensagens[3]);
            messages.dtAnoFaturamento = ScreenService.i18n(mensagens[4]);
            messages.semTipoFaturamento = ScreenService.i18n(mensagens[5]);
            messages.semNotas = ScreenService.i18n(mensagens[6]);
            messages.tipoApuracInvalido = ScreenService.i18n(mensagens[7]);
        });
    };
};
Configuration(function(ContextRegister, eventEngine) {
    ContextRegister.register('fac00100_calculo_de_apuracao_controller', fac00100_calculo_de_apuracao_controller);
});

// FILE: ./assets/js/controllers/fac00200_cancelamento_de_apuracao_controller.js
var fac00200_cancelamento_de_apuracao_controller = function(ScreenService, General, fac00200_cancelamento_de_apuracao_service, ZhPreferences, MessageService, ZhFilterPreferences) {
    var messages = {
        semUnidade: "Escolha um Unidade para definir a Companhia!",
        notaEmitTransf: "Cancelamento da apuração bloqueado! Existe(m) nota(s) emitida(s) ou transmitida(s) eletronicamente no período apurado.",
        confirmaCancelamento: "Confirma cancelamento?",
        sucessoCancelamento: "Cancelamento efetuado com sucesso.",
        semItensCancelamento: "Operação bloqueada.Não há itens a serem cancelados."
    };
    var self = this;
    var cia;

    this.setUserID = function() {
        ZhPreferences.setUserID(getLocalVar('CDOPERADOR'));
    };

    this.setDefaultFilial = function(widgetFilter) {
        var widget = widgetFilter.container.getWidget('fac00200_cancelamento_de_apuracao');
        if (widget.hasOwnProperty('appliedFilter')) {
            fac00200_cancelamento_de_apuracao_service.findFilial().then(function(callback) {
                var filial = callback.dataset.filial;
                widget.appliedFilter.FILTER_ROW.CDFILIAL = filial[0].CDFILIAL;
                widget.appliedFilter.FILTER_ROW.NMFILIAL = filial[0].NMFILIAL;
                widget.currentRow.CDFILIAL = filial[0].CDFILIAL;
                widget.currentRow.NMFILIAL = filial[0].NMFILIAL;
            });
        }
    };

    this.onChangeUnidade = function(widget) {
        widget.currentRow.NMCIA = '';
        widget.currentRow.NRAPURACFATM = '';
    };
    this.filterFieldCia = function(widget) {

        var field = widget.getField('NMCIA');
        var msg = "";
        if (widget.currentRow.CDFILIAL) {
            field.dataSourceFilter[0].value = widget.currentRow.CDFILIAL;
            field.reload();
        } else {
            field.dataSourceFilter[0].value = "";
            field.reload();
            // ScreenService.showMessage(messages.semUnidade, 'exclamation');
            MessageService.showMessageByCode("MSG_FAC_ESCOLHA_UNID_CIA");
        }

    };

    this.filterFieldApuracao = function(widget) {

        var filter = [
            {
                "name": "CDFILIAL",
                "operator": "=",
                "value": widget.currentRow.CDFILIAL
            },
            {
                "name": "CDCLIENTE",
                "operator": "=",
                "value": widget.currentRow.CDCLIENTE
            },
            {
                "name": "NRAPURACFATM",
                "operator": "=",
                "value": null
            }
        ];
        var field = widget.getField('NRAPURACFATM');
        field.dataSourceFilter = filter;
        field.reload();
    };
    this.filtraCancelamento = function(args, widget = args.owner) {
        if (widget) {
            let filterData = args.e.preference.FILTER_ROW;
            var filter = [
                {
                    name: "NRAPURACFATM",
                    operator: "=",
                    value: (filterData.NRAPURACFATM && filterData.NRAPURACFATM != "") ? filterData.NRAPURACFATM : "T"
                },
                {
                    name: "CDFILIAL",
                    operator: "=",
                    value: filterData.CDFILIAL
                },
                {
                    name: "CDCLIENTE",
                    operator: "=",
                    value: filterData.CDCLIENTE
                },
                {
                    name: "DTINICIAL",
                    operator: "=",
                    value: filterData.DTINICIAL
                },
                {
                    name: "DTFINAL",
                    operator: "=",
                    value: filterData.DTFINAL
                }
            ];

            widget.dataSourceFilter = filter;
            widget.reload();

        }

    };

    /**
     * Função para remover um objeto do array(filtro)
     * recebido como parâmetro.
     * 
     * @param {object} filter array com os objetos(filtros).
     * 
     * @param {int} objectIndex índice do objecto a ser removido
     * do array(filtro).
     */
    this.deleteFilterObject = function(filter, objectIndex) {

        if (objectIndex === 0) {
            filter.shift();
        } else if (objectIndex === filter.length - 1) {
            filter.pop();
        } else {
            filter = filter.slice(0, objectIndex).concat(filter.slice(objectIndex + 1));
        }

        return filter;
    };

    /**
     * Procedimento para recuperar a posição
     * de um objeto dentro de um array.
     * 
     * @param {object} array array onde será feito
     * a varredura.
     * 
     * @param {object} objectName nome do objeto a ser
     * buscado.
     */
    this.getObjectPositionInArrayByName = function(array, objectName) {

        var indexFieldObject;

        array.forEach(function(value, i) {
            if (value.name === objectName) {
                indexFieldObject = i;
            }
        });

        return indexFieldObject;

    };

    this.cancelaApuracao = function(widget) {

        var widgetData = widget.dataSource.data;

        if (widgetData && widgetData.length > 0) {

            if (!widget.appliedFilter) {
                // ScreenService.showMessage(messages.semItensCancelamento);
                MessageService.showMessageByCode("FAC00200_SEM_ITENS_CANCEL");
                return;
            }

            let filterData = widget.appliedFilter.FILTER_ROW;

            var data = [{
                "CDFILIAL": filterData.CDFILIAL,
                "CDCIA": filterData.CDCIA,
                "NRAPURACFATM": (filterData.NRAPURACFATM && filterData.NRAPURACFATM != "") ? filterData.NRAPURACFATM : "T",
                "DTINICIAL": filterData.DTINICIAL,
                "DTFINAL": filterData.DTFINAL
            }];
            var filter = [
                {
                    "name": "P_CDFILIAL",
                    "operator": "=",
                    "value": filterData.CDFILIAL
                },
                {
                    "name": "P_CDCLIENTE",
                    "operator": "=",
                    "value": filterData.CDCLIENTE
                },
                {
                    "name": "P_DATAINI",
                    "operator": "=",
                    "value": filterData.DTINICIAL
                },
                {
                    "name": "P_DATAFIN",
                    "operator": "=",
                    "value": filterData.DTFINAL
                },
                {
                    "name": "P_NRAPURACFATM",
                    "operator": "=",
                    "value": (filterData.NRAPURACFATM && filterData.NRAPURACFATM != "") ? filterData.NRAPURACFATM : "T"
                }
            ];
            // ScreenService.confirmMessage(messages.confirmaCancelamento).then(function() {
            MessageService.confirmMessageByCode("FAC00200_CONFIRM_CANCEL").then(() => {
                fac00200_cancelamento_de_apuracao_service.verificaNF(filter).then(function(callback) {
                    if (callback && callback.dataset.fac00200_verifica_nf.length) {
                        // ScreenService.showMessage(messages.notaEmitTransf, 'error');
                        MessageService.showMessageByCode("FAC00200_NOTA_EMIT_TRANSF");
                    } else {
                        fac00200_cancelamento_de_apuracao_service.procedureCancelamento(data).then(function(callback) {
                            widget.reload().then(function() {
                                // ScreenService.showMessage(messages.sucessoCancelamento, 'success');
                                MessageService.showMessageByCode("FAC00200_CANCEL_SUCES");
                            });
                        }, function(error) {
                            var errorMessage = 'Timeout';
                            if (error.data) errorMessage = error.data.error;
                            ScreenService.showMessage(errorMessage);
                        });
                    }
                });
            });

        } else {
            // ScreenService.showMessage(messages.semItensCancelamento);
            MessageService.showMessageByCode("FAC00200_SEM_ITENS_CANCEL");
        }

    };

    this.getMensagens = function() {
        MessageService.getMessagesByCode(["FAC00200_SEM_UNIDADE", "FAC00200_NOTA_EMIT_TRANSF",
                                          "FAC00200_CONF_CANCEL", "FAC00200_CANCEL_SUCES",
                                          "FAC00200_SEM_ITENS_CANCEL"]).then(function(mensagens) {
            messages.semUnidade = ScreenService.i18n(mensagens[0]);
            messages.notaEmitTransf = ScreenService.i18n(mensagens[1]);
            messages.confirmaCancelamento = ScreenService.i18n(mensagens[2]);
            messages.sucessoCancelamento = ScreenService.i18n(mensagens[3]);
            messages.semItensCancelamento = ScreenService.i18n(mensagens[4]);
        });
    };

    this.filterCia = function(field) {
        field.reload();
    };
};
Configuration(function(ContextRegister, eventEngine) {
    ContextRegister.register('fac00200_cancelamento_de_apuracao_controller', fac00200_cancelamento_de_apuracao_controller);
});

// FILE: ./assets/js/controllers/fac00500_faturamento_por_ciaController.js
/* global getLocalVar */
var fac00500_faturamento_por_ciaController = function(General, ScreenService, templateManager, FACUtil, MessageService) {

    this.setFilialLogada = function(args) {
        args.owner.currentRow.CDFILIAL = getLocalVar('INFLIGHTOR_CDFILIAL');
        args.owner.currentRow.NMFILIAL = getLocalVar('INFLIGHTOR_NMFILIAL');
    };

    this.onChangeUnit = function(fieldUnit) {
        const widget = fieldUnit.widget;
        const fieldsUpdate = ['NMCIA', 'NRVOO', 'DSCLASSECIA'];
        let rowFilter = FACUtil.getValuesInRow(widget, {
            NMFILIAL: 'CDFILIAL'
        }, 'CDCIA');
        FACUtil.clearFields(widget, fieldsUpdate);
        FACUtil.updateFilterFields(fieldsUpdate, ['CDFILIAL', 'CDCIA'], rowFilter, false, widget);
    };

    this.onChangeCia = function(fieldCia) {
        const widget = fieldCia.widget;
        const fieldsUpdate = ['NRVOO', 'DSCLASSECIA'];
        let rowFilter = FACUtil.getValuesInRow(widget, {
            NMCIA: 'CDCIA'
        });
        FACUtil.clearFields(widget, fieldsUpdate);
        FACUtil.updateFilterFields(fieldsUpdate, 'CDCIA', rowFilter, 'NRVOO', widget);
    };

    this.limpaField = function(field) {
        if (field.name == 'DTFINAL') {
            field.widget.currentRow.NRVOO = [];
        }
    };
    this.unidadeToCompanhia = function(field) {
        if (!field.widget.currentRow.CDFILIAL) {
            MessageService.showMessageByCode("MSG_FAC_ESCOLHA_UNID_CIA");
        }
    };

    this.validaCampos = function(args) {
        const field = args.owner.field;
        if (!field.widget.currentRow.CDCIA) {
            MessageService.showMessageByCode("MSG_FAC_ESCOLHA_CIA_VOO_TRECHO");
            args.e.preventDefault();
            return;
        }
        if (!field.widget.currentRow.DTINICIAL || !field.widget.currentRow.DTFINAL) {
            MessageService.showMessageByCode("MSG_FAC_ESCOLHA_PERIODO_VOO_TRECHO");
            args.e.preventDefault();
        }
    };
    this.filtraClasse = function(args) {
        const field = args.owner.field;
        var cdfilial = field.widget.currentRow.CDFILIAL;
        var cdcia = field.widget.currentRow.CDCIA;
        var filter = [
            {
                'name': 'CDFILIAL',
                'operator': '=',
                'value': cdfilial
            },
            {
                'name': 'CDCIA',
                'operator': '=',
                'value': cdcia
            }
        ];
        if (!field.widget.currentRow.CDCIA) {
            MessageService.showMessageByCode("MSG_FAC_ESCOLHA_CIA_CLASSE");
            args.e.preventDefault();
            return;
        }
        field.widget.getField('DSCLASSECIA').dataSourceFilter = filter;
        field.widget.getField('DSCLASSECIA').reload();
    };
    var validaDias = function(widget) {
        var dataInicial = widget.currentRow.DTINICIAL;
        dataInicial = moment(dataInicial, 'DD/MM/YYYY');
        widget.getField('DTFINAL').minDate = moment(dataInicial, 'DD/MM/YYYY');
    };
    this.habilitaFieldData = function(widget) {
        const fieldEndDate = widget.getField('DTFINAL');
        widget.currentRow.NRVOO = [];
        fieldEndDate.readOnly = true;
        if (widget.currentRow.DTINICIAL) {
            fieldEndDate.readOnly = false;
            validaDias(widget);
        }
    };

    this.gerarRelatorio = function(widget, format) {
        if (widget.isValid()) {
            if (widget.currentRow.TNRVOO != "T") {
                var voo = listaVoo(widget.getField('NRVOO'));
                widget.currentRow.VOO = voo;
            } else {
                widget.currentRow.VOO = 'T';
            }
            if (widget.currentRow.TCDCLASSE != "T") {
                var classe = listaClasse(widget.getField('DSCLASSECIA'));
                widget.currentRow.CLASSE = classe;
            } else {
                widget.currentRow.CLASSE = 'T';
            }
            widget.currentRow.REPORTFORMAT = format;
            General.openReport('fac#/faturamentocompanhiareport', widget.currentRow.REPORTNAME, widget.currentRow).then(function(callback) {
                widget.activate();
            }, function(error) {
                if (error.data) {
                    ScreenService.showMessage(error.data.error);
                } else {
                    MessageService.showMessageByCode("TIMEOUT");
                }
            });
        }
    };
    var listaClasse = function(field) {
        var lista = '';
        var rows = field.selectWidget.getCheckedRows();
        for (var i = 0; i < rows.length; i++) {
            if (lista == '') {
                lista = rows[i].CDCLASSE;
            } else {
                lista = lista + '_' + rows[i].CDCLASSE;
            }
        }
        return lista;
    };
    var listaVoo = function(field) {
        var lista = '';
        var rows = field.selectWidget.getCheckedRows();
        for (var i = 0; i < rows.length; i++) {
            if (lista == '') {
                lista = '_' + rows[i].NRVOO + rows[i].CDTRECHO;
            } else {
                lista = lista + '_' + rows[i].NRVOO + rows[i].CDTRECHO;
            }
            if (i == rows.length - 1) {
                lista += '_';
            }
        }
        return lista;
    };
    var listaEquipamento = function(field) {
        var lista = '';
        var rows = field.selectWidget.getCheckedRows();
        for (var i = 0; i < rows.length; i++) {
            if (lista == '') {
                lista = rows[i].CDCLASSE;
            } else {
                lista = lista + '_' + rows[i].CDCLASSE;
            }
        }
        return lista;
    };
    this.fieldOnChangeDsequip = function(args, field) {
        const widget = field.widget;
        let rowFilter = FACUtil.getValuesInRow(widget, {
            NMFILIAL: 'CDFILIAL',
            NMCIA: 'CDCIA'
        });
        FACUtil.updateFilterFields(field, ['CDFILIAL', 'CDCIA'], rowFilter);
        if (args.row.CDCIA) {
            field.reload();
        } else {
            MessageService.showMessageByCode("MSG_FAC_ESCOLHA_CIA_EQUIP");
            args.e.preventDefault();
        }
    };
};
Configuration(function(ContextRegister, eventEngine) {
    ContextRegister.register('fac00500_faturamento_por_ciaController', fac00500_faturamento_por_ciaController);
});

// FILE: ./assets/js/controllers/fac28500_faturamento_servicoController.js
var fac28500_faturamento_servicoController = function(General, ScreenService, templateManager, MessageService, FACUtil) {

    this.limpaField = function(field) {
        field.widget.currentRow.NMCIA = [];
        field.widget.currentRow.DSSERVICOCIAFILI = [];
    };

    this.beforeSelectOpenCia = function(args) {
        const fieldCia = args.owner.field;
        const widget = fieldCia.widget;
        const rowFilter = FACUtil.getValuesInRow(widget, {
            NMFILIAL: 'CDFILIAL'
        });
        if (args.row.CDFILIAL) {
            FACUtil.updateFilterFields(fieldCia, 'CDFILIAL', rowFilter, true);
        } else {
            MessageService.showMessageByCode("MSG_FAC_ESCOLHA_UNID_CIA");
            args.e.preventDefault();
        }
    };

    this.beforeSelectOpenServico = function(args) {
        const fieldServico = args.owner.field;
        const row = args.row;
        const {
            CDFILIAL,
            CDCIA,
            TCIA,
            NMCIA
        } = row;
        let filterUnit = fieldServico.dataSourceFilter.find(filter => filter.name == 'CDFILIAL');
        let filterCia = fieldServico.dataSourceFilter.find(filter => filter.name == 'CDCIA');
        const oldDataSourceFilter = angular.copy(fieldServico.dataSourceFilter);
        if (CDFILIAL || TCIA == 'S') {
            filterUnit.value = CDFILIAL;
            if (TCIA == 'S') {
                filterCia.value = "T";
                FACUtil.reloadField(fieldServico, oldDataSourceFilter);
            } else if (NMCIA && NMCIA.length) {
                filterCia.value = NMCIA.join('_');
                FACUtil.reloadField(fieldServico, oldDataSourceFilter);
            } else {
                MessageService.showMessageByCode("MSG_FAC_ESCOLHA_CIA_SERVICO");
                args.e.preventDefault();
            }
        } else {
            MessageService.showMessageByCode("MSG_FAC_ESCOLHA_UNID_CIA");
            args.e.preventDefault();
        }
    };

    this.validateDate = function(field) {
        var dataInicial = moment(field.widget.currentRow.DTINICIAL, 'DD/MM/YYYY');
        var dataFinal = moment(field.widget.currentRow.DTFINAL, 'DD/MM/YYYY');
        var dataMax = angular.copy(dataInicial);
        dataMax = dataMax.add(9, 'days');
        if (dataFinal.isBefore(dataInicial)) {
            MessageService.showMessageByCode('MSG_FAC_DATAINICIAL_MENOR_DATAFINAL');
            field.value(dataInicial.format('DD/MM/YYYY'));
        } else if (dataFinal.isAfter(dataMax)) {
            MessageService.showMessageByCode('MSG_FAC_DATAFINAL_MAIOR_LIMITE');
            field.value(dataMax.format('DD/MM/YYYY'));
        }
    };
    this.habilitaFieldData = function(widget) {
        widget.currentRow.NRVOO = [];
        widget.getField('DTFINAL').readOnly = true;
        if (widget.currentRow.DTINICIAL) {
            widget.getField('DTFINAL').readOnly = false;
        }
    };
    this.gerarRelatorio = function(widget) {
        var rowMontada = {};
        if (widget.isValid()) {
            if (widget.currentRow.TCIA == 'S') {
                rowMontada.CDCIA = 'T';
            } else {
                var CDCIA = "_";
                if (widget.currentRow.NMCIA !== "") {
                    widget.currentRow.NMCIA.forEach(function(row) {
                        CDCIA += row + "_";
                    });
                }
                rowMontada.CDCIA = CDCIA;
            }
            rowMontada.CDFILIAL = widget.currentRow.CDFILIAL;
            rowMontada.NRORG = widget.currentRow.NRORG;
            rowMontada.DATAINI = widget.currentRow.DTINICIAL;
            rowMontada.DATAFIN = widget.currentRow.DTFINAL;
            if (widget.currentRow.TSERVICOCIAFILI == 'S') {
                rowMontada.NRSERVICOCIAFILI = 'T';
            } else {
                var NRSERVICOCIAFILI = "_";
                if (widget.currentRow.DSSERVICOCIAFILI !== "") {
                    widget.currentRow.DSSERVICOCIAFILI.forEach(function(row) {
                        NRSERVICOCIAFILI += row + "_";
                    });
                }
                rowMontada.NRSERVICOCIAFILI = NRSERVICOCIAFILI;
            }
            General.openReport('fac#/faturamentoDoServico', widget.currentRow.REPORTNAME, rowMontada);
        }
    };
};
Configuration(function(ContextRegister, eventEngine) {
    ContextRegister.register('fac28500_faturamento_servicoController', fac28500_faturamento_servicoController);
});
