<?php

/**
* 05/10/2016
* @author Fabio Pereira
*/

namespace Teknisa\GER\Utilities;

use Teknisa\GER\Controllers\TeknisaCrud;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DTO\Response;

class MessagesProcedureInflightor extends TeknisaCrud
{

    protected $entityManager;
    protected $crudService;

    public function __construct ($crudService, $entityManager)
    {
        $this->crudService = $crudService;
        $this->entityManager = $entityManager;
    }

	public function concatErrorMessages($cdfilial, $nrlista, $response, $header = null, $returnToResponse = true){

		$sql = "SELECT DSERRO, MIN(NRORDEM) AS NRORDEM FROM LISTAERROS WHERE CDFILIAL = :CDFILIAL AND NRLISTA = :NRLISTA GROUP BY DSERRO ORDER BY NRORDEM";

		$params = array
		(
			"CDFILIAL" => $cdfilial,
			"NRLISTA"  => $nrlista
		);

		$query = $this->entityManager->getConnection()->prepare($sql);
        $query->execute($params);
        $result = $query->fetchAll();
        $erros = array();
        if($header){
        	array_push($erros, $header);
        }

        for ($i = 0; $i < count($result); $i++) {
		    $resultado = $this->convertMessage($result[$i]['DSERRO']);
		    array_push($erros, $resultado);
		};
		$sqlDelete = "DELETE FROM LISTAERROS WHERE CDFILIAL = :CDFILIAL AND NRLISTA = :NRLISTA";

		$queryDelete = $this->entityManager->getConnection()->prepare($sqlDelete);
        $queryDelete->execute($params);


        $dataSets=$response->getDataSets();
        $listaErros;
        foreach($dataSets as $dataSet) {
        	if($dataSet->getDataSourceName() == 'ListaErros'){
        		$listaErros = $dataSet;
        		break;
        	}
        }

        if(isset($listaErros)) {
        	$oldRows = $listaErros->getRows();
        	$erros = array_merge($erros, $oldRows);
        }
		if($returnToResponse){
        	return $response->addDataSet(new DataSet("ListaErros", $erros));
		} else {
			return $erros;
		}
	}

	public function convertMessage($message){
		$messageUpper 	= strtoupper($message);
		$codeStart	= strpos($messageUpper, "APPERRMSGSTR");
		$codeEnd	= strpos($messageUpper, "APPERRMSGEND");
		$maxParams	= 20;

		if ($codeStart !== FALSE && $codeEnd !== FALSE){
			$msgStart = $codeStart + 12;
			$msgEnd = $codeEnd - $msgStart;

	        $paramstring = substr($message, $msgStart, $msgEnd);

	        $param = explode("$$", $paramstring);

	        $code = array_shift($param);

	        $filler = array_fill(sizeof($param), $maxParams-sizeof($param), "");
	        $param = array_merge($param, $filler);

	        $messageConvert = $this->getMessage($code, $param);
	        $messageConvert = $messageConvert ? $messageConvert : $message;

	        return $messageConvert;
		}
		return $message;
	}

	public function getMessage($code, $param) {
		$messages = array(
			"APP-00001" => "Geração interrompida. Falta ciclo para esta data para a companhia $param[0]. Verifique a opção Frequência de Ciclo para esta companhia.",
			"APP-00002" => "Geração interrompida. O vôo $param[0] possui serviço(s) para a classe e esta não possui agrupamento de delivery cadastrado na opção 'Configuração de Passageiros'.  Verifique se este vôo seu prefixo ou equipamento possuem configuração de passageiros cadastradas corretamente.",
			"APP-00003" => "Geração interrompida. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo pertence a classe mas a quantidade de passageiros desta classe não foi informada. Verifique a previsão de passageiros informada para esta classe e tente novamente.",
			"APP-00004" => "Geração interrompida. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo possui proporção do tipo fixa, mas o valor da proporção não se encontra cadastrado. Verifique o item de faturamento na tabela de preços e tente novamente.",
			"APP-00005" => "Geração interrompida. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo possui proporção do tipo variável, mas não há valor cadastrado na tabela para a quantidade de passageiros ($param[3]). Verifique o item de faturamento na tabela de preços e tente novamente.",
			"APP-00006" => "Geração interrompida. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo possui proporção do tipo loading, mas o valor percentual do loading não se encontra cadastrado. Verifique o item de faturamento na tabela de preços e tente novamente.",
			"APP-00007" => "Geração interrompida. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo possui proporção do tipo quantidade fixa, mas o valor desta não se encontra cadastrado ou possui valor zero. Verifique o item de faturamento no voo ou o mesmo na tabela de preços e tente novamente.",
			"APP-00008" => "Geração interrompida. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] não possui preço cadastrado para esta data ou possui preço zero. Verifique se existe tabela de preço cadastrada para este serviço e se esta tabela se encontra vigente nesta data.",
			"APP-00009" => "Geração interrompida. Existe mais de uma tabela ativa no momento para a companhia $param[1]. Verifique a validade das tabelas de preço existentes e tente novamente.",
			"APP-00010" => "Geração interrompida. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] possui dois preços vigentes para o dia. Verifique a vigência do item de faturamento na tabela de preço e tente novamente.",
			"APP-00011" => "Geração interrompida. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] possui mais de um intervalo cadastrado para a quantidade do item ($param[3]) na tabela de preço proporcional. Verifique a tabela de preço proporcional e tente novamente.",
			"APP-00012" => "Geração interrompida. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] possui preço proporcional, mas não possui preço cadastrado para quantidade do item ($param[3]). Verifique a tabela de preço proporcional e tente novamente.",
			"APP-00013" => "Geração interrompida. O item de faturamento nacional $param[0] da classe: $param[1] e ciclo: $param[2] possui preço cadastrado apenas em dólar e näo há índce financeiro cadastrado para a data para fazer a conversão para Moeda Corrente. Verifique o cadastro de índice financeiro ou a tabela de preços e tente novamente.",
			"APP-00014" => "Geração interrompida. O item de faturamento internacional $param[0] da classe: $param[1] e ciclo: $param[2] possui preço cadastrado apenas na Moeda Corrente e näo há índce financeiro cadastrado para a data para fazer a conversão para dólar. Verifique o cadastro de índice financeiro ou a tabela de preços e tente novamente.",
			"APP-00015" => "Manuteção não permitida. O vôo já está cancelado.",
			"APP-00016" => "Não existe histórico para a companhia/vôo/trecho informados!",
			"APP-00017" => "Não existe configuração máxima de passageiros para o vôo $param[0], nem para seu prefixo e equipamento! Favor verificar em 'Configuração de Passageiros' e tentar novamente.",
			"APP-00018" => "Período bloqueado. Operação não permitida.",
			"APP-00019" => "Operação Bloqueada. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] possui preço proporcional e não está configurado como 1 por Pax.",
			"APP-00020" => "Voo ou trecho informado não encontrado.",
			"APP-00021" => "Não há dados para geração do retrobill para o período informado.",
			"APP-00022" => "Retrobill informado não encontrado.",
			"APP-00023" => "Operação bloqueada. Retrobill informado já foi aprovado.",
			"APP-00024" => "Operação bloqueada. Plano de voo já gerado para retrobill informado.",
			"APP-00025" => "Operação bloqueada. Não há valor a ser cobrado no retrobill.",
			"APP-00026" => "Operação bloqueada. Retrobill informado não está aprovado.",
			"APP-00027" => "Voo retrobill não parametrizado para a companhia.",
			"APP-00028" => "Não há trecho ativo para o voo retrobill.",
			"APP-00029" => "Agrupamento de delivery não encontrado para classe $param[0] nas configurações do voo $param[1] ou do equipamento $param[2] ou do prefixo $param[3].",
			"APP-00030" => "Operação bloqueada. Valor absoluto não deve ser maior que o total do retrobill.",
			"APP-00031" => "Operação bloqueada. Valor percentual não deve ser maior que 100%.",
			"APP-00032" => "Agrupamento de delivery do retrobill não parametrizado para a companhia.",
			"APP-00033" => "Tipo de apuração informado é inválido.",
			"APP-00034" => "Índice financeiro não cadastrado para a companhia.",
			"APP-00035" => "Produto para taxa de aeroporto nacional deve ser informado.",
			"APP-00036" => "Produto para taxa de aeroporto internacional deve ser informado.",
			"APP-00037" => "Companhia de código $param[0] não existe.",
			"APP-00038" => "Regeração do plano de vôo não permitida. Existem deliveries já emitidos para este vôo.",
			"APP-00039" => "Serviço genérico $param[0] não cadastrado para filial e companhia de destino.",
			"APP-00040" => "Classe $param[0] ou ciclo $param[1] não cadastrado para o serviço $param[2] na filial e companhia de destino.",
			"APP-00041" => "Serviço genérico $param[0] cadastrado mais de uma vez para filial e companhia de destino.",
			"APP-00042" => "Operação bloqueada. Não há menu grid vigente para a companhia em $param[0].",
			"APP-00043" => "Operação bloqueada. Não há tabela de preços vigente para a companhia em $param[0].",
			"APP-00044" => "Operação bloqueada. Serviço $param[0] da classe $param[1] e ciclo $param[2] não possui vínculo com o menu grid ativo da companhia.",
			"APP-00045" => "Ciclo $param[0] não cadastrado para o serviço $param[1] classe $param[2].",
			"APP-00046" => "Operação bloqueada. Manual de destino já está em proposta ou reprovado.",
			"APP-00047" => "Operação bloqueada. Este equipamento não possui configuração de handling / miscelânea.",
			"APP-00048" => "Operação bloqueada. Existem notas fiscais emitidas para os serviços relacionados.",
			"APP-00049" => "Operação bloqueada. Existem deliveries emitidas para os serviços relacionados. ",
			"APP-00050" => "Operação bloqueada. Existem deliveries canceladas para o plano de voo.",
			"APP-00051" => "Não há Produto para taxa de aeroporto cadastrado no agrupamento informado.",
			"APP-00052" => "Previsão da companhia $param[0] na data $param[1] já aprovada",
			"APP-00053" => "Previsão da data $param[0] já aprovada",
			"APP-00054" => "Previsão do voo $param[0] na data $param[1] já aprovada",
			"APP-00055" => "Operação bloqueada. Não há malha aérea configurada para a filial.",
			"APP-00056" => "Operação bloqueada. Existe previsão aprovada ou com checklist gerado para o voo $param[0] na data $param[1].",
			"APP-00057" => "Operação bloqueada. Existe mais de uma configuração na malha aérea para o voo $param[0] na data $param[1].",
			"APP-00058" => "Operação bloqueada. Número de previsão informado inválido.",
			"APP-00059" => "Não há dados para previsão do período informado",
			"APP-00060" => "Operação bloqueada. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo não está vinculado a um menu grid vigente e aprovado.",
			"APP-00061" => "Operação bloqueada. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo está vinculado a dois ou mais menu grids vigentes e aprovados.",
			"APP-00062" => "Operação bloqueada. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo está vinculado a mais de um serviço do menu grid.",
			"APP-00063" => "Operação bloqueada. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo não está vinculado a um subgrupo vigente do menu grid.",
			"APP-00064" => "Operação bloqueada. Já existe tabela de preço cadastrada para este período.",
			"APP-00065" => "Item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2]",
			"APP-00066" => "Operação bloqueada. Menu grid vigente difere do menu grid indicado na tabela de preços.",
			"APP-00067" => "Operação bloqueada. Item de faturamento $param[0] da classe $param[1] e ciclo $param[2] está vinculado a subgrupos com loading diferentes entre si e não está indicado como 1 por pax.",
			"APP-00068" => "Operação bloqueada. Item de faturamento $param[0] da classe $param[1] e ciclo $param[2] possui loading diferente do cadastrado no subgrupo vinculado.",
			"APP-00069" => "Item de faturamento $param[0] da classe $param[1] e ciclo $param[2] vinculado a mais de um menu grid",
			"APP-00070" => "Item de faturamento $param[0] da classe $param[1] e ciclo $param[2] não vinculado aos menu grids informados",
			"APP-00071" => "Item de faturamento $param[0] da classe $param[1] e ciclo $param[2] vinculado a dois ou mais serviços de menu grid $param[3]",
			"APP-00072" => "Item de faturamento $param[0] da classe $param[1] e ciclo $param[2] não vinculado a subgrupos do menu grid $param[3]",
			"APP-00073" => "Serviço $param[0] da classe: $param[1] e ciclo: $param[2]",
			"APP-00074" => "  A receita é utilizada na composição do Menu Grid: '$param[0]' pertencente à Companhia '$param[1]' da Unidade '$param[2]'",
			"APP-00075" => "  A subreceita é utilizada na composição da Receita:  '$param[0]' vinculada com o Menu Grid: '$param[1]' pertencente à Companhia '$param[2]' da Unidade '$param[3]'",
			"APP-00076" => "Operação bloqueada. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo está vinculado ao menu grid $param[3] mas esta relação não está indicada na tabela de preços.",
			"APP-00077" => "Operação bloqueada. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo está vinculado ao menu grid $param[3] mas o mesmo não se encontra aprovado.",
			"APP-00078" => "Operação bloqueada. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo está vinculado ao menu grid $param[3] mas o mesmo não se encontra vigente.",
			"APP-00079" => "Operação bloqueada. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo não está vinculado a um subgrupo vigente do menu grid $param[3].",
			"APP-00080" => "Operação bloqueada. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo está vinculado a mais de um item do menu grid $param[3].",
			"APP-00081" => "Operação bloqueada. O item de faturamento $param[0] da classe: $param[1] e ciclo: $param[2] do vôo está vinculado a subgrupos do menu grid $param[3] mas nenhum está vigente.",
			"APP-00082" => "Operação bloqueada. O item de faturamento $param[0] já está cadastrado no menu grid de destino e o mesmo se encontra aprovado.",
			"APP-00083" => "Operação bloqueada. Já existe plano de voo gerado para o voo $param[0] na data $param[1].",
			"APP-00084" => "Operação bloqueada. O item de faturamento $param[0] da classe $param[1] e ciclo $param[2] não possui tipo de loading informado na tabela de preço.",
			"APP-00085" => "Operação bloqueada. O item de faturamento $param[0] da classe $param[1] e ciclo $param[2] está vinculado a mais de um subgrupo com loading do tipo proporção fixa, com configurações de quantidade iguais entre si, e não está indicado como proporção fixa.",
			"APP-00086" => "Operação bloqueada. O item de faturamento $param[0] da classe $param[1] e ciclo $param[2] está vinculado a mais de um subgrupo com loading do tipo proporção fixa, com configurações de quantidade diferentes entre si, e não está indicado como 1 por pax.",
			"APP-00087" => "Operação bloqueada. O item de faturamento $param[0] da classe $param[1] e ciclo $param[2] está vinculado a mais de um subgrupo com loading do tipo tabela e não está indicado como 1 por pax.",
			"APP-00088" => "Operação bloqueada. O item de faturamento $param[0] da classe $param[1] e ciclo $param[2] está vinculado a mais de um subgrupo com loading do tipo percentual e não está indicado como 1 por pax.",
			"APP-00089" => "Operação bloqueada. O item de faturamento $param[0] da classe $param[1] e ciclo $param[2] está vinculado a mais de um subgrupo com loading do tipo quantidade fixa e não está indicado como quantidade fixa.",
			"APP-00090" => "Operação bloqueada. O item de faturamento $param[0] da classe $param[1] e ciclo $param[2] está vinculado a subgrupos vigentes cujo loading se encontra vazio.",
			"APP-00091" => "Operação bloqueada. Subgrupo não possui data de vigência informada ou a vigência é inválida",
			"APP-00092" => "Receita $param[0] - $param[1] está inativa",
			"APP-00093" => "Receita $param[0] - $param[1] está inativa e está em uso no ciclo $param[2] do subgrupo $param[3] do serviço $param[4] da classe $param[5] do menu grid $param[6] - $param[7] da companhia $param[8] na data $param[9]",
			"APP-00094" => "Receita $param[0] - $param[1] não possui variação para a unidade",
			"APP-00095" => "Receita $param[0] - $param[1] não possui variação para a unidade e está em uso no ciclo $param[2] do subgrupo $param[3] do serviço $param[4] da classe $param[5] do menu grid $param[6] - $param[7] da companhia $param[8] na data $param[9]",
			"APP-00096" => "Receita $param[0] - $param[1] não possui rendimento informado na variação dessa unidade",
			"APP-00097" => "Receita $param[0] - $param[1] não possui rendimento informado na variação dessa unidade e está em uso no ciclo $param[2] do subgrupo $param[3] do serviço $param[4] da classe $param[5] do menu grid $param[6] - $param[7] da companhia $param[8] na data $param[9]",
			"APP-00098" => "Receita flex $param[0] - $param[1] não possui número de opções definido na variação dessa unidade",
			"APP-00099" => "Receita flex $param[0] - $param[1] não possui número de opções definido na variação dessa unidade e está em uso no ciclo $param[2] do subgrupo $param[3] do serviço $param[4] da classe $param[5] do menu grid $param[6] - $param[7] da companhia $param[8] na data $param[9]",
			"APP-00100" => "Produto $param[0] - $param[1] está inativo e é utilizado na receita $param[2] - $param[3] na variação dessa unidade",
			"APP-00101" => "Produto $param[0] - $param[1] está inativo e é utilizado na receita $param[2] - $param[3] na variação dessa unidade e está em uso no ciclo  $param[4] do subgrupo $param[5] do serviço $param[6] da classe $param[7] do menu grid $param[8] - $param[9] da companhia $param[10] na data $param[11]",
			"APP-00102" => "Produto $param[0] - $param[1] está sem quantidade na receita $param[2] - $param[3] na variação dessa unidade",
			"APP-00103" => "Produto $param[0] - $param[1] está sem quantidade na receita $param[2] - $param[3] na variação dessa unidade e está em uso no ciclo  $param[4] do subgrupo $param[5] do serviço $param[6] da classe $param[7] do menu grid $param[8] - $param[9] da companhia $param[10] na data $param[11]",
			"APP-00104" => "Subreceita $param[0] - $param[1] está inativa e é utilizada na receita $param[2] - $param[3] na variação dessa unidade",
			"APP-00105" => "Subreceita $param[0] - $param[1] está inativa e é utilizada na receita $param[2] - $param[3] na variação dessa unidade e está em uso no ciclo  $param[4] do subgrupo $param[5] do serviço $param[6] da classe $param[7] do menu grid $param[8] - $param[9] da companhia $param[10] na data $param[11]",
			"APP-00106" => "Subreceita $param[0] - $param[1] está sem quantidade na receita $param[2] - $param[3] na variação dessa unidade",
			"APP-00107" => "Subreceita $param[0] - $param[1] está sem quantidade na receita $param[2] - $param[3] na variação dessa unidade e está em uso no ciclo  $param[4] do subgrupo $param[5] do serviço $param[6] da classe $param[7] do menu grid $param[8] - $param[9] da companhia $param[10] na data $param[11]",
			"APP-00108" => "Receita $param[0] - $param[1] não possui composição na variação dessa unidade",
			"APP-00109" => "Receita $param[0] - $param[1] não possui composição na variação dessa unidade e está em uso no ciclo $param[2] do subgrupo $param[3] do serviço $param[4] da classe $param[5] do menu grid $param[6] - $param[7] da companhia $param[8] na data $param[9]",
			"APP-00110" => "Receita flex $param[0] - $param[1] possui quantidade de opções a produzir inferior a quantidade de opções indicada na variação dessa unidade",
			"APP-00111" => "Receita flex $param[0] - $param[1] possui quantidade de opções a produzir inferior	 a quantidade de opções indicada na variação dessa unidade e está em uso no ciclo $param[2] do subgrupo $param[3] do serviço $param[4] da classe $param[5] do menu grid $param[6] - $param[7] da companhia $param[8] na data $param[9]",
			"APP-00112" => "Receita flex $param[0] - $param[1] possui quantidade de opções a produzir superior a quantidade de opções indicada na variação dessa unidade",
			"APP-00113" => "Receita flex $param[0] - $param[1] possui quantidade de opções a produzir superior a quantidade de opções indicada na variação dessa unidade e está em uso no ciclo $param[2] do subgrupo $param[3] do serviço $param[4] da classe $param[5] do menu grid $param[6] - $param[7] da companhia $param[8] na data $param[9]",
			"APP-00114" => "Receita $param[0] - $param[1] não possui padrão de produção cadastrado para a unidade informada e tipo de negócio $param[2] e é utilizada no ciclo $param[3] do subgrupo $param[4] do serviço $param[5] da classe $param[6] do menu grid $param[7] - $param[8] da companhia $param[9] na data $param[10]",
			"APP-00115" => "Receita $param[0] - $param[1] não possui tipo de produção cadastrado para a unidade informada no $param[2] do subgrupo $param[3] do serviço $param[4] da classe $param[5] do menu grid $param[6] - $param[7] da companhia $param[8] na data $param[9]",
			"APP-00116" => "Receita $param[0] - $param[1] não possui fluxo de produção definido para a unidade informada, setor $param[2], categoria $param[3], subcategoria $param[4], tipo de produção $param[5], voo $param[6] no ciclo $param[7] do subgrupo $param[8] do serviço $param[9] da classe $param[10] do menu grid $param[11] - $param[12] da companhia $param[13] na data $param[14]",
			"APP-00117" => "A previsão do dia $param[0] ainda não foi aprovada",
			"APP-00118" => "Não há menu grid vigente e aprovado para a companhia $param[0] na data $param[1]",
			"APP-00119" => "Há mais de um menu grid vigente e aprovado para a companhia $param[0] na data $param[1]",
			"APP-00120" => "Tipo de negócio não informado para o menu $param[0] - $param[1] da companhia $param[2]",
			"APP-00121" => "Não há tabela de preços vigente para a companhia $param[0] na data $param[1]",
			"APP-00122" => "Há mais de uma tabela de preços vigente para a companhia $param[0] na data $param[1]",
			"APP-00123" => "Há mais de um preço para o item de faturamento $param[0] da classe $param[1] do ciclo $param[2] na tabela ativa da companhia $param[3] na data $param[4]",
			"APP-00124" => "Não há preço para o item de faturamento $param[0] da classe $param[1] do ciclo $param[2] na tabela ativa da companhia $param[3] na data $param[4]",
			"APP-00125" => "Loading não foi informado para o subgrupo $param[0] do serviço $param[1] da classe $param[2] do menu grid $param[3] - $param[4] da companhia $param[5] na data $param[6]",
			"APP-00126" => "Quantidade do loading não foi informada para o subgrupo $param[0] do serviço $param[1] da classe $param[2] do menu grid $param[3] - $param[4] da companhia $param[5] na data $param[6]",
			"APP-00127" => "Não foi encontrada quantidade na tabela de loading do subgrupo $param[0] do serviço $param[1] da classe $param[2] do menu grid $param[3] - $param[4] para a quantidade de passageiros $param[5] do voo $param[6] na data $param[7]",
			"APP-00128" => "Operação bloqueada. Checklist $param[0] não aprovado pela produção.",
			"APP-00129" => "Operação bloqueada. Requisição $param[0] do checklist $param[1] já foi aprovada.",
			"APP-00130" => "Operação bloqueada. Atendimento $param[0] já gerado para a requisição $param[1] do checklist $param[2].",
			"APP-00131" => "Operação bloqueada. Planejamento $param[0] já aprovado.",
			"APP-00132" => "Checklist $param[0] está aprovado",
			"APP-00133" => "Checklist $param[0] possui requisição de número $param[1] relacionada",
			"APP-00134" => "Operação bloqueada. Planejamento $param[0] não está aprovado.",
			"APP-00135" => "Receita $param[0] - $param[1] não possui padrão de produção cadastrado para a unidade informada e tipo de negócio $param[2]",
			"APP-00136" => "Receita $param[0] - $param[1] não possui tipo de produção cadastrado para a unidade informada na classe $param[2] e companhia $param[3]",
			"APP-00137" => "Receita $param[0] - $param[1] não possui fluxo de produção definido para a unidade informada, setor $param[2], categoria $param[3], subcategoria $param[4], tipo de produção $param[5] e voo $param[6]",
			"APP-00138" => "Operação bloqueada. Solicitação $param[0] já aprovada.",
			"APP-00139" => "Operação bloqueada. Solicitação $param[0] não está aprovada.",
			"APP-00140" => "Operação bloqueada. Requisição $param[0] não está aprovada.",
			"APP-00141" => "Operação bloqueada. Atendimento $param[0] da requisição $param[1] já foi aprovado.", 
			"APP-00142" => "Não há horário de quebra definido para companhia $param[0]",
			"APP-00143" => "Não há horário de decolagem definido para o voo $param[0]",
			"APP-00144" => "Item de Faturamento $param[0] da classe $param[1] DO ciclo $param[2] do voo $param[3] na data $param[4] vinculado ao menu $param[5] - $param[6] que não está aprovado",
			"APP-00145" => "Item de Faturamento $param[0] da classe $param[1] DO ciclo $param[2] do voo $param[3] na data $param[4] vinculado ao menu $param[5] - $param[6] que não está vigente",
			"APP-00146" => "Item de Faturamento $param[0] da classe $param[1] DO ciclo $param[2] do voo $param[3] na data $param[4] não está vinculado a subgrupos vigentes",
			"APP-00147" => "Receita $param[0] - $param[1] não possui padrão de produção cadastrado para a unidade informada e tipo de negócio $param[2]",
			"APP-00148" => "Receita $param[0] - $param[1] não possui tipo de produção cadastrado para a unidade informada Na classe $param[2]",
			"APP-00149" => "Receita $param[0] - $param[1] não possui fluxo de produção definido para a unidade informada, setor $param[2], categoria $param[3], subcategoria $param[4] e tipo de produção $param[5]",
			"APP-00150" => "Percentual do bloco $param[0] não parametrizado nos parâmetros de produção da unidade"
		);
		if(!isset($messages[$code])){
			return false;
		}
		return $messages[$code];
	}
}